==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DiskPayloadSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DiskPayloadSpecFluent<A extends DiskPayloadSpecFluent<A>> extends BaseFluent<A>{
  public DiskPayloadSpecFluent() {
  }
  public DiskPayloadSpecFluent(DiskPayloadSpec instance) {
    instance = (instance != null ? instance : new DiskPayloadSpec());

    if (instance != null) {
      this.withPath(instance.getPath());
      this.withPayloadProcessNum(instance.getPayloadProcessNum());
      this.withSize(instance.getSize());
      this.withPath(instance.getPath());
      this.withPayloadProcessNum(instance.getPayloadProcessNum());
      this.withSize(instance.getSize());
    }
  }
  private String path;
  private Integer payloadProcessNum;
  private String size;
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public boolean hasPath() {
    return this.path != null;
  }
  public Integer getPayloadProcessNum() {
    return this.payloadProcessNum;
  }
  public A withPayloadProcessNum(Integer payloadProcessNum) {
    this.payloadProcessNum=payloadProcessNum; return (A) this;
  }
  public boolean hasPayloadProcessNum() {
    return this.payloadProcessNum != null;
  }
  public String getSize() {
    return this.size;
  }
  public A withSize(String size) {
    this.size=size; return (A) this;
  }
  public boolean hasSize() {
    return this.size != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiskPayloadSpecFluent that = (DiskPayloadSpecFluent) o;
    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(payloadProcessNum, that.payloadProcessNum)) return false;

    if (!java.util.Objects.equals(size, that.size)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  payloadProcessNum,  size,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (payloadProcessNum != null) { sb.append("payloadProcessNum:"); sb.append(payloadProcessNum + ","); }
    if (size != null) { sb.append("size:"); sb.append(size); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/DiskPayloadSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DiskPayloadSpecFluent<A extends DiskPayloadSpecFluent<A>> extends BaseFluent<A>{
  public DiskPayloadSpecFluent() {
  }
  
  public DiskPayloadSpecFluent(DiskPayloadSpec instance) {
    this.copyInstance(instance);
  }
  private String path;
  private Integer payloadProcessNum;
  private String size;
  
  protected void copyInstance(DiskPayloadSpec instance) {
    instance = (instance != null ? instance : new DiskPayloadSpec());
  
    if (instance != null) {
        this.withPath(instance.getPath());
        this.withPayloadProcessNum(instance.getPayloadProcessNum());
        this.withSize(instance.getSize());
        this.withPath(instance.getPath());
        this.withPayloadProcessNum(instance.getPayloadProcessNum());
        this.withSize(instance.getSize());
      }
  }
  
  public String getPath() {
    return this.path;
  }
  
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  
  public boolean hasPath() {
    return this.path != null;
  }
  
  public Integer getPayloadProcessNum() {
    return this.payloadProcessNum;
  }
  
  public A withPayloadProcessNum(Integer payloadProcessNum) {
    this.payloadProcessNum=payloadProcessNum; return (A) this;
  }
  
  public boolean hasPayloadProcessNum() {
    return this.payloadProcessNum != null;
  }
  
  public String getSize() {
    return this.size;
  }
  
  public A withSize(String size) {
    this.size=size; return (A) this;
  }
  
  public boolean hasSize() {
    return this.size != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DiskPayloadSpecFluent that = (DiskPayloadSpecFluent) o;
    if (!java.util.Objects.equals(path, that.path)) return false;
  
    if (!java.util.Objects.equals(payloadProcessNum, that.payloadProcessNum)) return false;
  
    if (!java.util.Objects.equals(size, that.size)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(path,  payloadProcessNum,  size,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (payloadProcessNum != null) { sb.append("payloadProcessNum:"); sb.append(payloadProcessNum + ","); }
    if (size != null) { sb.append("size:"); sb.append(size); }
    sb.append("}");
    return sb.toString();
  }
  

}
